// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KGAPI_VERSION_H
#define KGAPI_VERSION_H

#define KGAPI_VERSION_STRING "6.4.3"
#define KGAPI_VERSION_MAJOR 6
#define KGAPI_VERSION_MINOR 4
#define KGAPI_VERSION_PATCH 3
#define KGAPI_VERSION ((6<<16)|(4<<8)|(3))

#endif
